CalendarEventStore

Struct CalendarEventStore 

pub struct CalendarEventStore(pub HashMap<Date, Style>);
Available on crate feature calendar only.
A simple DateStyler based on a HashMap

Tuple Fields

0: HashMap<Date, Style>

Implementations

Source

impl CalendarEventStore

pub fn today<S: Into<Style>>(style: S) -> Self

Available on crate feature std only.

Construct a store that has the current date styled.

style accepts any type that is convertible to Style (e.g. Style, Color, or your own type that implements Into<Style>).

pub fn add<S: Into<Style>>(&mut self, date: Date, style: S)

Add a date and style to the store

style accepts any type that is convertible to Style (e.g. Style, Color, or your own type that implements Into<Style>).